@@ -38,6 +38,14 @@ AICc <-
                        nobs = nobs)
     }
 
+
+    ##determine if unmarked
+    unmarked.class <- c("unmarkedFitOccu", "unmarkedFitColExt", "unmarkedFitOccuRN", "unmarkedFitPCount", "unmarkedFitPCO")
+    if(any(sapply(unmarked.class, FUN = function(i) identical(i, class(mod))))) {
+      aicc <- AICc.unmarked(mod = mod, return.K = return.K, c.hat = c.hat, second.ord = second.ord,
+                            nobs = nobs)
+    }
+        
     
 
     ##if(class(mod)[1]=="nlm") {aicc <- AICc.nlm(mod, return.K)}      #determine if object from nlm optimizer
